==> haskell-store-core-0.4.4.7-34-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-store-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 store-core
version:              0.4.4.7
visibility:           public
id:                   store-core-0.4.4.7-JFYq5lzTFcT9mVcH6OQnna
key:                  store-core-0.4.4.7-JFYq5lzTFcT9mVcH6OQnna
license:              MIT
copyright:            2016 FP Complete
maintainer:           Michael Sloan <mgsloan@gmail.com>
homepage:             https://github.com/fpco/store#readme
synopsis:             Fast and lightweight binary serialization
category:             Serialization, Data
abi:                  8bd4dfa17ebf6793f780ef5d5e3ec292
exposed:              True
exposed-modules:      Data.Store.Core
hidden-modules:       Paths_store_core
import-dirs:          /usr/lib/ghc-9.4.8/site-local/store-core-0.4.4.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/store-core-0.4.4.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/store-core-0.4.4.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-store-core
hs-libraries:         HSstore-core-0.4.4.7-JFYq5lzTFcT9mVcH6OQnna
depends:
    base-4.17.2.1 bytestring-0.11.5.3 ghc-prim-0.9.1
    primitive-0.8.0.0-2MtTSGoMYmP3ESqdIhZDu7 text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-store-core/html/store-core.haddock
haddock-html:         /usr/share/doc/haskell-store-core/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-store-core-0.4.4.7-35-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-store-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 store-core
version:              0.4.4.7
visibility:           public
id:                   store-core-0.4.4.7-Bbvd5bBG7slC5bouNkPKX5
key:                  store-core-0.4.4.7-Bbvd5bBG7slC5bouNkPKX5
license:              MIT
copyright:            2016 FP Complete
maintainer:           Michael Sloan <mgsloan@gmail.com>
homepage:             https://github.com/fpco/store#readme
synopsis:             Fast and lightweight binary serialization
category:             Serialization, Data
abi:                  163c58859eb5106f8440a6b2a1ecfdc6
exposed:              True
exposed-modules:      Data.Store.Core
hidden-modules:       Paths_store_core
import-dirs:          /usr/lib/ghc-9.4.8/site-local/store-core-0.4.4.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/store-core-0.4.4.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/store-core-0.4.4.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-store-core
hs-libraries:         HSstore-core-0.4.4.7-Bbvd5bBG7slC5bouNkPKX5
depends:
    base-4.17.2.1 bytestring-0.11.5.3 ghc-prim-0.9.1
    primitive-0.8.0.0-1110YmBHzhAERV5HY7EG3e text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-store-core/html/store-core.haddock
haddock-html:         /usr/share/doc/haskell-store-core/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
